import { HexEncodedString } from '../../utils';
/**
 * All of the block issuer key types.
 */
declare enum BlockIssuerKeyType {
    /** An Ed25519 public key hash block issuer key. */
    Ed25519PublicKeyHash = 0
}
/** The base class for a block issuer key. */
declare abstract class BlockIssuerKey {
    readonly type: BlockIssuerKeyType;
    /**
     * @param type The type of block issuer key.
     */
    constructor(type: BlockIssuerKeyType);
}
/**
 * Ed25519 public key hash Block Issuer Key.
 */
declare class Ed25519PublicKeyHashBlockIssuerKey extends BlockIssuerKey {
    /**
     * An Ed25519 public key hash.
     */
    readonly pubKeyHash: HexEncodedString;
    constructor(pubKeyHash: HexEncodedString);
}
declare const BlockIssuerKeyDiscriminator: {
    property: string;
    subTypes: {
        value: typeof Ed25519PublicKeyHashBlockIssuerKey;
        name: any;
    }[];
};
export { BlockIssuerKeyDiscriminator, BlockIssuerKey, BlockIssuerKeyType, Ed25519PublicKeyHashBlockIssuerKey, };
